@@ -86,5 +86,5 @@ class MainTools():
                 print(f'{ticket_kinds.get(kind)[0]}的号码是 -->> {ticket_kinds.get(kind)[1]()}')
             print('*' * 20)
 
-    def create_article(self, theme):
-        create_article_main(theme)
+    def create_article(self, theme, line_num):
+        create_article_main(theme, line_num)
